@@ -3,17 +3,21 @@ import lxml.etree as ET
 def do_nothing(obj):
     return obj
 
-class FastXPath(ET.XPath):
+class FastXPath():
     def __init__(self, xpath, *args, many=False, **kwargs):
         self.many = many
-        if many:
-            super().__init__(xpath, *args, **kwargs)
-        else:
+        self.args = args
+        self.kwargs = kwargs
+        if not many:
             xpath = f"({xpath})[1]"
-            super().__init__(xpath, *args, **kwargs)
+        self.xpath = xpath
+        self.create_xpath_obj()
     
+    def create_xpath_obj(self):
+        self.xpath_obj = ET.XPath(self.xpath, *self.args, **self.kwargs)
+
     def __call__(self, *args, **kwargs):
-        result = super().__call__(*args, **kwargs)
+        result = self.xpath_obj(*args, **kwargs)
         if self.many:
             return result
         elif result:
@@ -21,6 +25,15 @@ class FastXPath(ET.XPath):
         else:
             return None
 
+    def __getstate__(self):
+        state = self.__dict__.copy()
+        del state['xpath_obj']
+        return state
+
+    def __setstate__(self, state):
+        self.__dict__.update(state)
+        self.create_xpath_obj()
+
 class XmlMixin(object):
     def make_accessor(self):
         namespaces = getattr(self.Meta, "namespaces", dict())
@@ -31,7 +44,11 @@ class XmlMixin(object):
     def to_string(self, elem):
         if isinstance(elem, str):
             return elem
-        return "".join(elem.itertext())
+        try:
+            return "".join(elem.itertext())
+        except ValueError:
+            # Occasionally elements won't have itertext available
+            return elem.text
 
     def convert_groupdict(self, dictionary):
         root = ET.Element("root")
